<?php 
/*
Plugin Name: Disable WP Automatic Updates
Description: Disable updates for plugins, themes and Wordpress core.
Plugin Uri: http://stefaniq.com
Author: Ciprian Craciun
Version: 1.0
Author URI: http://stefaniq.com
Donate link: https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=crcn_ciprian%40yahoo.com&item_name=Plugin+Development%3A+Disable+Core+Updates&currency_code=EUR&source=url
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

if( !defined( 'CCDWPU_VER' ) )
	define( 'CCDWPU_VER', '1.0' );

if (!class_exists('CC_Disable_WP_Updates')) {
    class CC_Disable_WP_Updates {

        // singleton class instance
        static $instance = false;
        
        private function __construct() {
            add_action( 'admin_init', array(&$this, 'admin_init') );
        }

        /**
         * if an instance exists, then return it. If not it creates one and return it.
         */
        public static function getInstance() {
            if (!self::$instance)
                self::$instance == new self;
            return self::$instance;
        }

        public function admin_init() {
            if ( !function_exists("remove_action") ) return;


            // wordpress core updates
            add_filter( 'pre_site_transient_update_core', '__return_null' );
            add_filter( 'auto_update_core', '__return_false' );
            add_filter( 'allow_dev_auto_core_updates', '__return_false' );           // Disable development updates 
            add_filter( 'allow_minor_auto_core_updates', '__return_false' );         // Disable minor updates
            add_filter( 'allow_major_auto_core_updates', '__return_false' );         // Disable major updates


            add_filter('site_transient_update_themes','themes_updates');

            add_filter( 'site_transient_update_plugins', 'plugin_updates');

            add_filter('http_request_args', 'prevent_plugin_update_check', 10, 2);           // Prevent plugins check

            add_filter('http_request_args', 'prevent_themes_update_check', 10, 2);           // Prevent themes check
            

        }

        // Disable plugin update check
        function prevent_plugin_update_check($r, $url) {
            if (0 === strpos($url,'http://api.wordpress.org/plugins/update-check/')){
                $my_plugin = plugin_basename(__FILE__);
                $plugins = unserialize($r['body']['plugins']);
                unset($plugins->plugins[$my_plugin]);
                unset($plugins->active[array_search($my_plugin, $plugins->active )]);
                $r['body']['plugins'] = serialize($plugins);
            }
            return $r;
        }

        /**
         * Disable themes update check
         */
        public function prevent_themes_update_check($res, $url) {
            if (0 !== strpos($url, 'https://api.wordpress.org/themes/update-check' )) return $res;
            
            $themes = unserialize( $r['body']['themes'] );
            unset( $themes[ get_option( 'template' ) ] );
            unset( $themes[ get_option( 'stylesheet' ) ] );
            $res['body']['themes'] = serialize( $themes );
            return $res;
        }

        /**
         * Disable plugins updates
         */
        public function plugin_updates( $value ) {
            unset( $value->response);
            return $value;
        }

        /**
         * Disable themes updates
         */

        public function themes_updates( $value ) {
            unset( $value->response);
            return $value;
        }

    }

    $CC_Disable_WP_Updates = CC_Disable_WP_Updates::getInstance();
}

?>